<?php

declare(strict_types=1);

namespace FiloBlu\ExtMailChimp\Observer;

use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;

class FillSubscriberDataOnCreation implements ObserverInterface
{

    public function execute(Observer $observer)
    {
        $subscriber = $observer->getEvent()->getSubscriber();
        $postParams = $observer->getEvent()->getPostParams();
        $customer = $observer->getEvent()->getCustomer();

        $data = [];

        foreach($postParams as $key => $value) {
            switch($key) {
                case 'country_id':
                    $data['country'] = $value;
                    $data["filoblu_country"] = $value;
                    break;
                case 'email':
                case 'firstname':
                case 'lastnane':
                case 'language':
                case 'phone':
                case 'privacy':
                case 'gender':
                case 'collections':
                case 'website_name':
                case 'source':
                    $data[$key] = $value;
                    $data["filoblu_{$key}"] = $value;
                    break;
                case 'dob-newsletter-value':
                    $data['dob'] = $value;
                    $data['filoblu_dob'] = $value;
                    break;
                case 'dob-newsletter-birthday':
                    $data['birthday'] = $value;
                    $data['filoblu_birthday'] = $value;
                    break;
            }
        }

        $data['type'] = 'GUEST';

        if ($customer && $customer->getData() && $customer->isLoggedIn()) {
            if (strcasecmp($data['email'], $customer->getEmail()) == 0) {
                $data['type'] = 'CUSTOMER';
            }
        }

        $data['filoblu_type'] = $data['type'];

        $subscriber->addData($data);
    }
}
